%% Initialize and run scripts for give-way scenario
%% Author:  Jakob Stensvik Jensen
%% Date:    4/6-2020
clc
close all

%% Simulation parameters
t_stop = 200;                           % Simulation time
h = 0.01;                               % Step size
mu = 0.1;                               % Non-negative tuning constant
Delta_p_1 = 0.1;                        % Gain for hyperbolic function
u_d = 0.1;                              % Reference speed
p_0 = [-14 -2];                         % Initial position
eta_0 = [p_0 atan2(-p_0(2),-p_0(1))]';  % Initial position and heading
v_c = [0.0071;-0.0071];                 % Current velocity

%% Hybrid path parametrization 
lambda = 2;                             % Positive design parameter
r = 3;                                  % Number of differentiability
length_wp_list = 10;                    % Length of WP list
init_wp_list = zeros(2,length_wp_list); % Initial WP list

% Initializing list of WPs
init_wp_list(:,1) = eta_0(1:2);
for i = 2:length_wp_list     
    init_wp_list(:,i) = [0+eps*(i-2);0];
end

%% Navigation function parameters
R = 1;                                      % Circle of acceptance radius  

% Workspace and partition parameters
Lx = 30;                                    % Length of workspace in x
Ly = 30;                                    % Length of workspace in y
Nx  =  30;                                  % Number of cells in x
Ny  =  30;                                  % Number of cells in y

% TS parameters
r_TS = 0.5;                      	% Radius of TS
lambda_psi = 0.001;             	% Weight on heading change
p_0TS = [-5.8 6.2];                 % Initial position of TS
vel_TS = [-0.0164;-6*0.0164];   	% Velocity of TS             
kappa = 12;                     	% Tuning parameter
d_0 = 3.2;                          % Neighborhood radius

% COLREGs parameters
r_HO = 2*r_TS;          % Radius of virtual obstacles in head-on scenario
n_HO = 4;               % Number of virtual obstacles in head-on scenario
r_GW = 3*r_TS;          % Radius of virtual obstacles in give-way scenario

%% Controller gains
T_1 = diag([2 1 1]);            % Time constants for z_1-subsystem
T_2 = diag([1 0.8 0.5]);        % Time constants for z_2-subsystem

%% Observer gains
L_1 = diag([0.05 0.5 0.75]);    % Eta gain matrix   
L_2 = diag([5 12.5 2.5]);       % Nu gain matrix             
L_3 = diag([0.15 0.7 0.15]);    % Bias gain matrix    

%% Run scripts   
model_matrices          % Load matrices for control design model     
sim('Simulation_CSEI'); % Simulate
plotscript_giveway      % Plots for give-way scenario