%% Animate
%% Author:  Jakob Stensvik Jensen
%% Date:    4/6-2020 
close all

%% Prepare the new file.
vidObj = VideoWriter('simulation','MPEG-4');
vidObj.Quality = 100;
vidObj.FrameRate=15;
open(vidObj);

%% Create an animation.
set(gca,'nextplot','replacechildren');
figure('units','pixels','position',[0 0 1920 960]) 

% Parameters
wp=[p_0 p_t];
L=0.9;

j=1;
for i = 1:100:length(eta)
    % Nominal path
    plot(wp(2,:), wp(1,:),'--','Color',[0.8500 0.3250 0.0980])
    hold on
    % Combined path
    plot(eta_d(1:i,2),eta_d(1:i,1),'Color',[0 0.4470 0.7410]) 
    % Real path
    plot(eta(1:i,2),eta(1:i,1),'Color',[0.8500 0.3250 0.0980])
    % Path of TS
    if vel_TS(1)>=0
        x=linspace(p_0TS(1),20,100);
    else
        x=linspace(-20,p_0TS(1),100);
    end
    plot(vel_TS(2)/vel_TS(1).*(x - p_0TS(1))+p_0TS(2),x,'--','Color',...
        [0 0.4470 0.7410])
    % WPs
    plot(wp(2,1), wp(1,1),'r*')
    t=text(wp(2,1)-1,wp(1,1),'$p_0$','FontSize',11);
    t.Interpreter='latex';
    plot(wp(2,2), wp(1,2),'r*')
    t=text(wp(2,2)+1,wp(1,2),'$p_t$','FontSize',11);
    t.Interpreter='latex';
    % Position of q_d
    plot(q_d(i,2), q_d(i,1),'ko','LineWidth',1.5,...
                            'MarkerEdgeColor','k',...
                            'MarkerFaceColor','k',...
                            'MarkerSize',1.5)
    % Normal vector from q_d to p_d
    plot([q_d(i,2),eta_d(i,2)],[q_d(i,1), eta_d(i,1)],':','Color',...
        [0.4940 0.1840 0.5560],'LineWidth',1.5)
    % Position of p_d
    plot(eta_d(i,2), eta_d(i,1),'ko','LineWidth',1.5,...
                                'MarkerEdgeColor','k',...
                                'MarkerFaceColor','k',...
                                'MarkerSize',1.5)
    % Outline of OS
    R0 = [cos(eta(i,3)) -sin(eta(i,3)); sin(eta(i,3)) cos(eta(i,3))];
    ship = R0*[6*L/9 4*L/9 -5*L/9 -5*L/9 4*L/9 6*L/9; 0 1.2*L/9 1.2*L/9 ...
        -1.2*L/9 -1.2*L/9 0];
    plot(eta(i,2)+ship(2,:), eta(i,1)+ship(1,:),'k');
    % Timer
    t=text(wp(2,2)+7,wp(1,2),['Timer: ',num2str(floor(i/100)),'s'],...
        'FontSize',11);
    t.Interpreter='latex';
    % Outline of TS
    pos = [(p_TS(i,2)-r_TS) (p_TS(i,1)-r_TS) 1 1]; 
    rectangle('Position',pos,'Curvature',[1 1])

    x_label = xlabel('East [m]','FontSize',11);
    y_label = ylabel('North [m]','FontSize',11);
    x_label.Interpreter = 'latex';
    y_label.Interpreter = 'latex';
    set(gca,'FontSize',11);
    grid on
    if p_t(1)>=p_0(1)
        ylim([p_0(1)-1.5 p_t(1)+1.5])
    else
        ylim([p_t(1)-1.5 p_0(1)+1.5])
    end
    axis equal
    set(gca,'TickLabelInterpreter','latex')
    ylim([p_0(1)-1.5 p_t(1)+1.5])
    xlim([(p_t(2)+p_0(2))/2-21.45/2,(p_t(2)+p_0(2))/2+21.45/2])
    h_legend=legend('$q_d$','$p_d$','$p$','$p_{TS}$','$p_0$','$p_t$',...
        '$q_d$','$q_N$','$p_d$');
    set(h_legend,'Orientation','vertical','location','northwest',...
        'FontSize',11,'Color','None','Interpreter','latex');
    h_title=title(...
        'The desired and real path of the OS and the path of the TS',...
        'FontSize',11);
    h_title.Interpreter = 'latex';

    currFrame = getframe(gcf);
    writeVideo(vidObj,currFrame);
    hold off
end

%% Close the file.
close(vidObj);