%% Plot give-way scenario
%% Author:  Jakob Stensvik Jensen
%% Date:    4/6-2020 
close all

%% Estimated bias
figure(1)
subplot(3,1,1);
plot(time(:,1),bias_hat(:,1),'Color',[0.8500 0.3250 0.0980])
y_label = ylabel('$b_1$ [N]','FontSize',11);
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$\hat{b}_1$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
h_title = title('The estimated bias','FontSize',11);
h_title.Interpreter = 'latex';
grid on 
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])
pos = get(gca, 'Position');
pos(2) = 0.688;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])
subplot(3,1,2);
plot(time(:,1),bias_hat(:,2),'Color',[0.8500 0.3250 0.0980])
y_label = ylabel('$b_2$ [N]','FontSize',11);
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$\hat{b}_2$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
grid on
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])
pos = get(gca, 'Position');
pos(2) = 0.399;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])
subplot(3,1,3);
plot(time(:,1),bias_hat(:,3),'Color',[0.8500 0.3250 0.0980])
x_label = xlabel('Time [s]','FontSize',11);
y_label = ylabel('$b_3$ [Nm]','FontSize',11);
x_label.Interpreter = 'latex';
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$\hat{b}_3$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
grid on
set(gca,'TickLabelInterpreter','latex')
pos = get(gca, 'Position');
pos(2) = 0.11;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])

%% Real and estimated velocities
figure(2)
subplot(3,1,1);
plot(time(:,1),nu(:,1))
hold on
plot(time(:,1),nu_hat(:,1))
y_label = ylabel('$v_u$ [m/s]','FontSize',11);
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$v_u$','$\hat{v}_u$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
h_title = title('The real and estimated velocities','FontSize',11);
h_title.Interpreter = 'latex';
grid on 
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])
pos = get(gca, 'Position');
pos(2) = 0.688;
pos(4) = 0.239;
set(gca, 'Position', pos)
ax = gca;
ax.YAxis.Exponent = -1;
xlim([0,t_stop])
subplot(3,1,2);
plot(time(:,1),nu(:,2))
hold on
plot(time(:,1),nu_hat(:,2))
y_label = ylabel('$v_v$ [m/s]','FontSize',11);
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$v_v$','$\hat{v}_v$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
grid on
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])
pos = get(gca, 'Position');
pos(2) = 0.399;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])
subplot(3,1,3);
plot(time(:,1),nu(:,3)*180/pi)
hold on
plot(time(:,1),nu_hat(:,3)*180/pi)
x_label = xlabel('Time [s]','FontSize',11);
y_label = ylabel('$r$ [deg/s]','FontSize',11);
x_label.Interpreter = 'latex';
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$r$','$\hat{r}$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
grid on
set(gca,'TickLabelInterpreter','latex')
pos = get(gca, 'Position');
pos(2) = 0.11;
pos(4) = 0.239;
set(gca, 'Position', pos)
ax = gca;
ax.YAxis.Exponent = -1;
xlim([0,t_stop])

%% Measured and estimated position and heading
figure(3)
subplot(3,1,1);
plot(time(:,1),y_m(:,1))
hold on
plot(time(:,1),eta_hat(:,1))
y_label = ylabel('$x$ [m]','FontSize',11);
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$x_m$','$\hat{x}$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
h_title = title('The measured and estimated position and heading',...
    'FontSize',11);
h_title.Interpreter = 'latex';
grid on 
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])
pos = get(gca, 'Position');
pos(2) = 0.688;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])
subplot(3,1,2);
plot(time(:,1),y_m(:,2))
hold on
plot(time(:,1),eta_hat(:,2))
y_label = ylabel('$y$ [m]','FontSize',11);
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$y_m$','$\hat{y}$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
grid on
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])
pos = get(gca, 'Position');
pos(2) =  0.399;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])
subplot(3,1,3);
plot(time(:,1),y_m(:,3)*180/pi)
hold on
plot(time(:,1),eta_hat(:,3)*180/pi)
x_label = xlabel('Time [s]','FontSize',11);
y_label = ylabel('$\psi$ [deg]','FontSize',11);
x_label.Interpreter = 'latex';
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$\psi_m$','$\hat{\psi}$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
grid on
set(gca,'TickLabelInterpreter','latex')
pos = get(gca, 'Position');
pos(2) = 0.11;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])

%% Desired and real forces and moment
figure(4);
subplot(3,1,1);
plot(time(:,1),tau(:,1),'Linewidth',1.2)
hold on
plot(time(:,1),tau_thr_dyn(:,1))
ylim([-0.4 0.2])
y_label = ylabel('$X$ [N]','FontSize',11);
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$X_d$','$X$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
h_title = title('The desired and real forces and moment','FontSize',11);
h_title.Interpreter = 'latex';
grid on 
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])
pos = get(gca, 'Position');
pos(2) = 0.688;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])
subplot(3,1,2);
plot(time(:,1),tau(:,2),'Linewidth',1.2)
hold on
plot(time(:,1),tau_thr_dyn(:,2))
ylim([-0.3 0.2])
y_label = ylabel('$Y$ [N]','FontSize',11);
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$Y_d$','$Y$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
grid on
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])
pos = get(gca, 'Position');
pos(2) = 0.399;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])
subplot(3,1,3);
plot(time(:,1),tau(:,3),'Linewidth',1.2)
hold on
plot(time(:,1),tau_thr_dyn(:,3))
ylim([-0.1 0.1])
x_label = xlabel('Time [s]','FontSize',11);
y_label = ylabel('$N$ [Nm]','FontSize',11);
x_label.Interpreter = 'latex';
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$N_d$','$N$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
grid on
set(gca,'TickLabelInterpreter','latex')
pos = get(gca, 'Position');
pos(2) = 0.11;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])

%% Desired and real position and heading
figure(5)
subplot(3,1,1);
plot(time(:,1),eta_d(:,1))
hold on
plot(time(:,1),eta(:,1))
y_label = ylabel('$x$ [m]','FontSize',11);
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$x_d$','$x$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
h_title = title('The desired and real position and heading','FontSize',11);
h_title.Interpreter = 'latex';
grid on 
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])
pos = get(gca, 'Position');
pos(2) = 0.688;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])
subplot(3,1,2);
plot(time(:,1),eta_d(:,2))
hold on
plot(time(:,1),eta(:,2))
y_label = ylabel('$y$ [m]','FontSize',11);
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$y_d$','$y$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
grid on
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])
pos = get(gca, 'Position');
pos(2) = 0.399;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])
subplot(3,1,3);
plot(time(:,1),eta_d(:,3)*180/pi)
hold on
plot(time(:,1),eta(:,3)*180/pi)
x_label = xlabel('Time [s]','FontSize',11);
y_label = ylabel('$\psi$ [deg]','FontSize',11);
x_label.Interpreter = 'latex';
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend = legend('$\psi_d$','$\psi$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
grid on
set(gca,'TickLabelInterpreter','latex')
pos = get(gca, 'Position');
pos(2) = 0.11;
pos(4) = 0.239;
set(gca, 'Position', pos)
xlim([0,t_stop])

%% Paths and outlines of OS and TS
figure(6) 
% Nominal path
plot(wp(2,:), wp(1,:),'--','Color',[0.8500    0.3250    0.0980])
hold on
% Combined path
plot(eta_d(:,2),eta_d(:,1),'Color',[     0    0.4470    0.7410])
L=0.9;
% Real path
plot(eta(:,2),eta(:,1),'Color',[0.8500    0.3250    0.0980])
% Path of TS
if vel_TS(1)>=0
    x=linspace(p_0TS(1),20,100);
else
    x=linspace(-20,p_0TS(1),100);
end
plot(vel_TS(2)/vel_TS(1).*(x - p_0TS(1))+p_0TS(2),x,'--','Color',...
    [0 0.447 0.741])
% WPs
plot(wp(2,1), wp(1,1),'r*')
plot(wp(2,2), wp(1,2),'r*')
t=text(wp(2,1)-1.5,wp(1,1),'$p_0$','FontSize',11);
t.Interpreter='latex';
t=text(wp(2,2)+1.5,wp(1,2),'$p_t$','FontSize',11);
t.Interpreter='latex';
% Outlines of OS
j=1;
for i = 1:1500:length(eta)
    if j < -1
        R0 = [cos(eta(i,3)) -sin(eta(i,3)); sin(eta(i,3)) cos(eta(i,3))];
        ship = R0*[6*L/9 4*L/9 -5*L/9 -5*L/9 4*L/9 6*L/9; 0 1.2*L/9 ...
            1.2*L/9 -1.2*L/9 -1.2*L/9 0];
        plot(eta(i,2)+ship(2,:), eta(i,1)+ship(1,:),'k');
        vec=R0*[-0.4;-0.9];
        t=text(eta(i,2)+ship(2,2)+vec(2),eta(i,1)+ship(1,2)+vec(1),...
            num2str(j),'FontSize',11);
        t.Interpreter='latex';
        j=j+1;
     elseif j==6
        R0 = [cos(eta(i,3)) -sin(eta(i,3)); sin(eta(i,3)) cos(eta(i,3))];
        ship = R0*[6*L/9 4*L/9 -5*L/9 -5*L/9 4*L/9 6*L/9; 0 1.2*L/9 ...
            1.2*L/9 -1.2*L/9 -1.2*L/9 0];
        plot(eta(i,2)+ship(2,:), eta(i,1)+ship(1,:),'k');
        vec=R0*[-0.8;0.2];
        t=text(eta(i,2)+ship(2,2)+vec(2),eta(i,1)+ship(1,2)+vec(1),...
            num2str(j),'FontSize',11);
        t.Interpreter='latex';
        j=j+1;
    elseif j==11
        R0 = [cos(eta(i,3)) -sin(eta(i,3)); sin(eta(i,3)) cos(eta(i,3))];
        ship = R0*[6*L/9 4*L/9 -5*L/9 -5*L/9 4*L/9 6*L/9; 0 1.2*L/9 ...
            1.2*L/9 -1.2*L/9 -1.2*L/9 0];
        plot(eta(i,2)+ship(2,:), eta(i,1)+ship(1,:),'k');
        vec=R0*[-0.2;0.2];
        t=text(eta(i,2)+ship(2,2)+vec(2),eta(i,1)+ship(1,2)+vec(1),...
            num2str(j),'FontSize',11);
        t.Interpreter='latex';
        j=j+1;
    elseif j==12
        R0 = [cos(eta(i,3)) -sin(eta(i,3)); sin(eta(i,3)) cos(eta(i,3))];
        ship = R0*[6*L/9 4*L/9 -5*L/9 -5*L/9 4*L/9 6*L/9; 0 1.2*L/9 ...
            1.2*L/9 -1.2*L/9 -1.2*L/9 0];
        plot(eta(i,2)+ship(2,:), eta(i,1)+ship(1,:),'k');
        vec=R0*[0.43;-0.16];
        t=text(eta(i,2)+ship(2,2)+vec(2),eta(i,1)+ship(1,2)+vec(1),...
            num2str(j),'FontSize',11);
        t.Interpreter='latex';
        j=j+1;
    elseif j==13
        R0 = [cos(eta(i,3)) -sin(eta(i,3)); sin(eta(i,3)) cos(eta(i,3))];
        ship = R0*[6*L/9 4*L/9 -5*L/9 -5*L/9 4*L/9 6*L/9; 0 1.2*L/9 ...
            1.2*L/9 -1.2*L/9 -1.2*L/9 0];
        plot(eta(i,2)+ship(2,:), eta(i,1)+ship(1,:),'k');
        vec=R0*[0.37;-0.89];
        t=text(eta(i,2)+ship(2,2)+vec(2),eta(i,1)+ship(1,2)+vec(1),...
            num2str(j),'FontSize',11);
        t.Interpreter='latex';
        j=j+1;
    elseif j==14
        R0 = [cos(eta(i,3)) -sin(eta(i,3)); sin(eta(i,3)) cos(eta(i,3))];
        ship = R0*[6*L/9 4*L/9 -5*L/9 -5*L/9 4*L/9 6*L/9; 0 1.2*L/9 ...
            1.2*L/9 -1.2*L/9 -1.2*L/9 0];
        plot(eta(i,2)+ship(2,:), eta(i,1)+ship(1,:),'k');
        vec=R0*[-0.25;-1.1];
        t=text(eta(i,2)+ship(2,2)+vec(2),eta(i,1)+ship(1,2)+vec(1),...
            num2str(j),'FontSize',11);
        t.Interpreter='latex';
        j=j+1;
    else
        R0 = [cos(eta(i,3)) -sin(eta(i,3)); sin(eta(i,3)) cos(eta(i,3))];
        ship = R0*[6*L/9 4*L/9 -5*L/9 -5*L/9 4*L/9 6*L/9; 0 1.2*L/9 ...
            1.2*L/9 -1.2*L/9 -1.2*L/9 0];
        plot(eta(i,2)+ship(2,:), eta(i,1)+ship(1,:),'k');
        vec=R0*[-0.2;0.1];
        t=text(eta(i,2)+ship(2,2)+vec(2),eta(i,1)+ship(1,2)+vec(1),...
            num2str(j),'FontSize',11);
        t.Interpreter='latex';
        j=j+1;
    end
end
% Outlines of TS
j=1;
for i = 1:1500:length(p_TS)
        if j ==16
            pos = [(p_TS(i,2)-r_TS) (p_TS(i,1)-r_TS) 1 1]; 
            rectangle('Position',pos,'Curvature',[1 1])
            vec=[-1;0.3];
            t=text(p_TS(i,2)-r_TS+vec(2),p_TS(i,1)+vec(1),...
                [num2str(j),'*'],'FontSize',11);
            t.Interpreter='latex';
            j=j+1;
        elseif j==14
        else
            pos = [(p_TS(i,2)-r_TS) (p_TS(i,1)-r_TS) 1 1]; 
            rectangle('Position',pos,'Curvature',[1 1])
            vec=[-0.9;0.3];
            t=text(p_TS(i,2)-r_TS+vec(2),p_TS(i,1)+vec(1),...
                [num2str(j),'*'],'FontSize',11);
            t.Interpreter='latex';
            j=j+1;
        end
end
x_label = xlabel('East [m]','FontSize',11);
y_label = ylabel('North [m]','FontSize',11);
x_label.Interpreter = 'latex';
y_label.Interpreter = 'latex';
set(gca,'FontSize',11);
h_legend=legend('$q_d$','$p_d$','$p$','$p_{TS}$','$p_0$','$p_t$');
set(h_legend,'Orientation','vertical','location','best','FontSize',...
    11,'Color','None','Interpreter','latex');
h_title=title(...
    'The desired and real path of the OS and the path of the TS',...
    'FontSize',11);
h_title.Interpreter = 'latex';
grid on
if p_t(1)>=p_0(1)
    ylim([p_0(1)-1.5 p_t(1)+1.5])
else
    ylim([p_t(1)-1.5 p_0(1)+1.5])
end
axis equal
set(gca,'TickLabelInterpreter','latex')
ylim([p_0(1)-1.5 p_t(1)+1.5])
xlim([-1-21.45/2,-1+21.45/2])